# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mobilecoind_api.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import .external_pb2 as external__pb2
import .blockchain_pb2 as blockchain__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='mobilecoind_api.proto',
  package='mobilecoind_api',
  syntax='proto3',
  serialized_options=b'\n\032com.mobilecoin.mobilecoindB\016MobileCoinDAPI',
  serialized_pb=b'\n\x15mobilecoind_api.proto\x12\x0fmobilecoind_api\x1a\x1bgoogle/protobuf/empty.proto\x1a\x0e\x65xternal.proto\x1a\x10\x62lockchain.proto\"B\n\x06Outlay\x12\r\n\x05value\x18\x01 \x01(\x04\x12)\n\x08receiver\x18\x02 \x01(\x0b\x32\x17.external.PublicAddress\"\xd6\x01\n\x0cUnspentTxOut\x12\x1f\n\x06tx_out\x18\x01 \x01(\x0b\x32\x0f.external.TxOut\x12\x18\n\x10subaddress_index\x18\x02 \x01(\x04\x12%\n\tkey_image\x18\x03 \x01(\x0b\x32\x12.external.KeyImage\x12\r\n\x05value\x18\x04 \x01(\x04\x12\x1e\n\x16\x61ttempted_spend_height\x18\x05 \x01(\x04\x12!\n\x19\x61ttempted_spend_tombstone\x18\x06 \x01(\x04\x12\x12\n\nmonitor_id\x18\n \x01(\x0c\"\xd9\x02\n\nTxProposal\x12\x31\n\ninput_list\x18\x01 \x03(\x0b\x32\x1d.mobilecoind_api.UnspentTxOut\x12,\n\x0boutlay_list\x18\x02 \x03(\x0b\x32\x17.mobilecoind_api.Outlay\x12\x18\n\x02tx\x18\x03 \x01(\x0b\x32\x0c.external.Tx\x12\x0b\n\x03\x66\x65\x65\x18\x04 \x01(\x04\x12^\n\x1coutlay_index_to_tx_out_index\x18\x05 \x03(\x0b\x32\x38.mobilecoind_api.TxProposal.OutlayIndexToTxOutIndexEntry\x12#\n\x1boutlay_confirmation_numbers\x18\x06 \x03(\x0c\x1a>\n\x1cOutlayIndexToTxOutIndexEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\"P\n\x0fSenderTxReceipt\x12*\n\x0ekey_image_list\x18\x01 \x03(\x0b\x32\x12.external.KeyImage\x12\x11\n\ttombstone\x18\x02 \x01(\x04\"\xba\x01\n\x11ReceiverTxReceipt\x12*\n\trecipient\x18\x01 \x01(\x0b\x32\x17.external.PublicAddress\x12\x34\n\rtx_public_key\x18\x02 \x01(\x0b\x32\x1d.external.CompressedRistretto\x12\x13\n\x0btx_out_hash\x18\x03 \x01(\x0c\x12\x11\n\ttombstone\x18\x04 \x01(\x04\x12\x1b\n\x13\x63onfirmation_number\x18\x05 \x01(\x0c\"\xa5\x01\n\rMonitorStatus\x12)\n\x0b\x61\x63\x63ount_key\x18\x01 \x01(\x0b\x32\x14.external.AccountKey\x12\x18\n\x10\x66irst_subaddress\x18\x02 \x01(\x04\x12\x18\n\x10num_subaddresses\x18\x03 \x01(\x04\x12\x13\n\x0b\x66irst_block\x18\x04 \x01(\x04\x12\x12\n\nnext_block\x18\x05 \x01(\x04\x12\x0c\n\x04name\x18\x06 \x01(\t\"\xfa\x01\n\x0eProcessedTxOut\x12\x12\n\nmonitor_id\x18\x01 \x01(\x0c\x12\x18\n\x10subaddress_index\x18\x02 \x01(\x04\x12\x31\n\npublic_key\x18\x03 \x01(\x0b\x32\x1d.external.CompressedRistretto\x12%\n\tkey_image\x18\x04 \x01(\x0b\x32\x12.external.KeyImage\x12\r\n\x05value\x18\x05 \x01(\x04\x12;\n\tdirection\x18\x06 \x01(\x0e\x32(.mobilecoind_api.ProcessedTxOutDirection\x12\x14\n\x0c\x61\x64\x64ress_code\x18\x07 \x01(\t\"\x95\x01\n\x11\x41\x64\x64MonitorRequest\x12)\n\x0b\x61\x63\x63ount_key\x18\x01 \x01(\x0b\x32\x14.external.AccountKey\x12\x18\n\x10\x66irst_subaddress\x18\x02 \x01(\x04\x12\x18\n\x10num_subaddresses\x18\x03 \x01(\x04\x12\x13\n\x0b\x66irst_block\x18\x04 \x01(\x04\x12\x0c\n\x04name\x18\x05 \x01(\t\"(\n\x12\x41\x64\x64MonitorResponse\x12\x12\n\nmonitor_id\x18\x01 \x01(\x0c\"*\n\x14RemoveMonitorRequest\x12\x12\n\nmonitor_id\x18\x01 \x01(\x0c\"1\n\x16GetMonitorListResponse\x12\x17\n\x0fmonitor_id_list\x18\x01 \x03(\x0c\"-\n\x17GetMonitorStatusRequest\x12\x12\n\nmonitor_id\x18\x01 \x01(\x0c\"J\n\x18GetMonitorStatusResponse\x12.\n\x06status\x18\x01 \x01(\x0b\x32\x1e.mobilecoind_api.MonitorStatus\"J\n\x1aGetUnspentTxOutListRequest\x12\x12\n\nmonitor_id\x18\x01 \x01(\x0c\x12\x18\n\x10subaddress_index\x18\x02 \x01(\x04\"Q\n\x1bGetUnspentTxOutListResponse\x12\x32\n\x0boutput_list\x18\x01 \x03(\x0b\x32\x1d.mobilecoind_api.UnspentTxOut\"*\n\x17GenerateEntropyResponse\x12\x0f\n\x07\x65ntropy\x18\x01 \x01(\x0c\"\'\n\x14GetAccountKeyRequest\x12\x0f\n\x07\x65ntropy\x18\x01 \x01(\x0c\"B\n\x15GetAccountKeyResponse\x12)\n\x0b\x61\x63\x63ount_key\x18\x01 \x01(\x0b\x32\x14.external.AccountKey\"G\n\x17GetPublicAddressRequest\x12\x12\n\nmonitor_id\x18\x01 \x01(\x0c\x12\x18\n\x10subaddress_index\x18\x02 \x01(\x04\"K\n\x18GetPublicAddressResponse\x12/\n\x0epublic_address\x18\x01 \x01(\x0b\x32\x17.external.PublicAddress\"*\n\x16ReadRequestCodeRequest\x12\x10\n\x08\x62\x35\x38_code\x18\x01 \x01(\t\"a\n\x17ReadRequestCodeResponse\x12)\n\x08receiver\x18\x01 \x01(\x0b\x32\x17.external.PublicAddress\x12\r\n\x05value\x18\x02 \x01(\x04\x12\x0c\n\x04memo\x18\x03 \x01(\t\"_\n\x15GetRequestCodeRequest\x12)\n\x08receiver\x18\x01 \x01(\x0b\x32\x17.external.PublicAddress\x12\r\n\x05value\x18\x02 \x01(\x04\x12\x0c\n\x04memo\x18\x03 \x01(\t\"*\n\x16GetRequestCodeResponse\x12\x10\n\x08\x62\x35\x38_code\x18\x01 \x01(\t\"+\n\x17ReadTransferCodeRequest\x12\x10\n\x08\x62\x35\x38_code\x18\x01 \x01(\t\"\x9c\x01\n\x18ReadTransferCodeResponse\x12\x0f\n\x07\x65ntropy\x18\x01 \x01(\x0c\x12\x34\n\rtx_public_key\x18\x02 \x01(\x0b\x32\x1d.external.CompressedRistretto\x12\x0c\n\x04memo\x18\x03 \x01(\t\x12+\n\x04utxo\x18\x04 \x01(\x0b\x32\x1d.mobilecoind_api.UnspentTxOut\"m\n\x16GetTransferCodeRequest\x12\x0f\n\x07\x65ntropy\x18\x01 \x01(\x0c\x12\x34\n\rtx_public_key\x18\x02 \x01(\x0b\x32\x1d.external.CompressedRistretto\x12\x0c\n\x04memo\x18\x03 \x01(\t\"+\n\x17GetTransferCodeResponse\x12\x10\n\x08\x62\x35\x38_code\x18\x01 \x01(\t\"*\n\x16ReadAddressCodeRequest\x12\x10\n\x08\x62\x35\x38_code\x18\x01 \x01(\t\"D\n\x17ReadAddressCodeResponse\x12)\n\x08receiver\x18\x01 \x01(\x0b\x32\x17.external.PublicAddress\"B\n\x15GetAddressCodeRequest\x12)\n\x08receiver\x18\x01 \x01(\x0b\x32\x17.external.PublicAddress\"*\n\x16GetAddressCodeResponse\x12\x10\n\x08\x62\x35\x38_code\x18\x01 \x01(\t\"\xca\x01\n\x11GenerateTxRequest\x12\x19\n\x11sender_monitor_id\x18\x01 \x01(\x0c\x12\x19\n\x11\x63hange_subaddress\x18\x02 \x01(\x04\x12\x31\n\ninput_list\x18\x03 \x03(\x0b\x32\x1d.mobilecoind_api.UnspentTxOut\x12,\n\x0boutlay_list\x18\x04 \x03(\x0b\x32\x17.mobilecoind_api.Outlay\x12\x0b\n\x03\x66\x65\x65\x18\x05 \x01(\x04\x12\x11\n\ttombstone\x18\x06 \x01(\x04\"F\n\x12GenerateTxResponse\x12\x30\n\x0btx_proposal\x18\x01 \x01(\x0b\x32\x1b.mobilecoind_api.TxProposal\"G\n\x1dGenerateOptimizationTxRequest\x12\x12\n\nmonitor_id\x18\x01 \x01(\x0c\x12\x12\n\nsubaddress\x18\x02 \x01(\x04\"R\n\x1eGenerateOptimizationTxResponse\x12\x30\n\x0btx_proposal\x18\x01 \x01(\x0b\x32\x1b.mobilecoind_api.TxProposal\"\xc5\x01\n\x1dGenerateTransferCodeTxRequest\x12\x19\n\x11sender_monitor_id\x18\x01 \x01(\x0c\x12\x19\n\x11\x63hange_subaddress\x18\x02 \x01(\x04\x12\x31\n\ninput_list\x18\x03 \x03(\x0b\x32\x1d.mobilecoind_api.UnspentTxOut\x12\r\n\x05value\x18\x04 \x01(\x04\x12\x0b\n\x03\x66\x65\x65\x18\x05 \x01(\x04\x12\x11\n\ttombstone\x18\x06 \x01(\x04\x12\x0c\n\x04memo\x18\x07 \x01(\t\"\xb9\x01\n\x1eGenerateTransferCodeTxResponse\x12\x30\n\x0btx_proposal\x18\x01 \x01(\x0b\x32\x1b.mobilecoind_api.TxProposal\x12\x0f\n\x07\x65ntropy\x18\x02 \x01(\x0c\x12\x34\n\rtx_public_key\x18\x03 \x01(\x0b\x32\x1d.external.CompressedRistretto\x12\x0c\n\x04memo\x18\x04 \x01(\t\x12\x10\n\x08\x62\x35\x38_code\x18\x05 \x01(\t\"\xb6\x01\n\x1eGenerateTxFromTxOutListRequest\x12)\n\x0b\x61\x63\x63ount_key\x18\x01 \x01(\x0b\x32\x14.external.AccountKey\x12\x31\n\ninput_list\x18\x02 \x03(\x0b\x32\x1d.mobilecoind_api.UnspentTxOut\x12)\n\x08receiver\x18\x03 \x01(\x0b\x32\x17.external.PublicAddress\x12\x0b\n\x03\x66\x65\x65\x18\x04 \x01(\x04\"S\n\x1fGenerateTxFromTxOutListResponse\x12\x30\n\x0btx_proposal\x18\x01 \x01(\x0b\x32\x1b.mobilecoind_api.TxProposal\"C\n\x0fSubmitTxRequest\x12\x30\n\x0btx_proposal\x18\x01 \x01(\x0b\x32\x1b.mobilecoind_api.TxProposal\"\x95\x01\n\x10SubmitTxResponse\x12;\n\x11sender_tx_receipt\x18\x01 \x01(\x0b\x32 .mobilecoind_api.SenderTxReceipt\x12\x44\n\x18receiver_tx_receipt_list\x18\x02 \x03(\x0b\x32\".mobilecoind_api.ReceiverTxReceipt\"?\n\x15GetLedgerInfoResponse\x12\x13\n\x0b\x62lock_count\x18\x01 \x01(\x04\x12\x11\n\ttxo_count\x18\x02 \x01(\x04\"$\n\x13GetBlockInfoRequest\x12\r\n\x05\x62lock\x18\x01 \x01(\x04\"B\n\x14GetBlockInfoResponse\x12\x17\n\x0fkey_image_count\x18\x01 \x01(\x04\x12\x11\n\ttxo_count\x18\x02 \x01(\x04\"m\n\x19\x41rchiveBlockSignatureData\x12\x0f\n\x07src_url\x18\x01 \x01(\t\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\x12-\n\tsignature\x18\x03 \x01(\x0b\x32\x1a.blockchain.BlockSignature\" \n\x0fGetBlockRequest\x12\r\n\x05\x62lock\x18\x01 \x01(\x04\"\xbb\x01\n\x10GetBlockResponse\x12 \n\x05\x62lock\x18\x01 \x01(\x0b\x32\x11.blockchain.Block\x12>\n\nsignatures\x18\x02 \x03(\x0b\x32*.mobilecoind_api.ArchiveBlockSignatureData\x12&\n\nkey_images\x18\x03 \x03(\x0b\x32\x12.external.KeyImage\x12\x1d\n\x04txos\x18\x04 \x03(\x0b\x32\x0f.external.TxOut\"O\n\x1aGetTxStatusAsSenderRequest\x12\x31\n\x07receipt\x18\x01 \x01(\x0b\x32 .mobilecoind_api.SenderTxReceipt\"H\n\x1bGetTxStatusAsSenderResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.mobilecoind_api.TxStatus\"g\n\x1cGetTxStatusAsReceiverRequest\x12\x33\n\x07receipt\x18\x01 \x01(\x0b\x32\".mobilecoind_api.ReceiverTxReceipt\x12\x12\n\nmonitor_id\x18\x02 \x01(\x0c\"J\n\x1dGetTxStatusAsReceiverResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.mobilecoind_api.TxStatus\"=\n\x18GetProcessedBlockRequest\x12\x12\n\nmonitor_id\x18\x01 \x01(\x0c\x12\r\n\x05\x62lock\x18\x02 \x01(\x04\"M\n\x19GetProcessedBlockResponse\x12\x30\n\x07tx_outs\x18\x01 \x03(\x0b\x32\x1f.mobilecoind_api.ProcessedTxOut\"A\n\x11GetBalanceRequest\x12\x12\n\nmonitor_id\x18\x01 \x01(\x0c\x12\x18\n\x10subaddress_index\x18\x02 \x01(\x04\"%\n\x12GetBalanceResponse\x12\x0f\n\x07\x62\x61lance\x18\x01 \x01(\x04\"\x98\x01\n\x12SendPaymentRequest\x12\x19\n\x11sender_monitor_id\x18\x01 \x01(\x0c\x12\x19\n\x11sender_subaddress\x18\x02 \x01(\x04\x12,\n\x0boutlay_list\x18\x03 \x03(\x0b\x32\x17.mobilecoind_api.Outlay\x12\x0b\n\x03\x66\x65\x65\x18\x04 \x01(\x04\x12\x11\n\ttombstone\x18\x05 \x01(\x04\"\xca\x01\n\x13SendPaymentResponse\x12;\n\x11sender_tx_receipt\x18\x01 \x01(\x0b\x32 .mobilecoind_api.SenderTxReceipt\x12\x44\n\x18receiver_tx_receipt_list\x18\x02 \x03(\x0b\x32\".mobilecoind_api.ReceiverTxReceipt\x12\x30\n\x0btx_proposal\x18\x03 \x01(\x0b\x32\x1b.mobilecoind_api.TxProposal\"\x87\x02\n\x18GetNetworkStatusResponse\x12#\n\x1bnetwork_highest_block_index\x18\x01 \x01(\x04\x12^\n\x14peer_block_index_map\x18\x02 \x03(\x0b\x32@.mobilecoind_api.GetNetworkStatusResponse.PeerBlockIndexMapEntry\x12\x19\n\x11local_block_index\x18\x03 \x01(\x04\x12\x11\n\tis_behind\x18\x04 \x01(\x08\x1a\x38\n\x16PeerBlockIndexMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01*`\n\x08TxStatus\x12\x0b\n\x07Unknown\x10\x00\x12\x0c\n\x08Verified\x10\x01\x12\x1a\n\x16TombstoneBlockExceeded\x10\x02\x12\x1d\n\x19InvalidConfirmationNumber\x10\x03*?\n\x17ProcessedTxOutDirection\x12\x0b\n\x07Invalid\x10\x00\x12\x0c\n\x08Received\x10\x01\x12\t\n\x05Spent\x10\x02\x32\x95\x16\n\x0eMobilecoindAPI\x12W\n\nAddMonitor\x12\".mobilecoind_api.AddMonitorRequest\x1a#.mobilecoind_api.AddMonitorResponse\"\x00\x12P\n\rRemoveMonitor\x12%.mobilecoind_api.RemoveMonitorRequest\x1a\x16.google.protobuf.Empty\"\x00\x12S\n\x0eGetMonitorList\x12\x16.google.protobuf.Empty\x1a\'.mobilecoind_api.GetMonitorListResponse\"\x00\x12i\n\x10GetMonitorStatus\x12(.mobilecoind_api.GetMonitorStatusRequest\x1a).mobilecoind_api.GetMonitorStatusResponse\"\x00\x12r\n\x13GetUnspentTxOutList\x12+.mobilecoind_api.GetUnspentTxOutListRequest\x1a,.mobilecoind_api.GetUnspentTxOutListResponse\"\x00\x12U\n\x0fGenerateEntropy\x12\x16.google.protobuf.Empty\x1a(.mobilecoind_api.GenerateEntropyResponse\"\x00\x12`\n\rGetAccountKey\x12%.mobilecoind_api.GetAccountKeyRequest\x1a&.mobilecoind_api.GetAccountKeyResponse\"\x00\x12i\n\x10GetPublicAddress\x12(.mobilecoind_api.GetPublicAddressRequest\x1a).mobilecoind_api.GetPublicAddressResponse\"\x00\x12\x66\n\x0fReadRequestCode\x12\'.mobilecoind_api.ReadRequestCodeRequest\x1a(.mobilecoind_api.ReadRequestCodeResponse\"\x00\x12\x63\n\x0eGetRequestCode\x12&.mobilecoind_api.GetRequestCodeRequest\x1a\'.mobilecoind_api.GetRequestCodeResponse\"\x00\x12i\n\x10ReadTransferCode\x12(.mobilecoind_api.ReadTransferCodeRequest\x1a).mobilecoind_api.ReadTransferCodeResponse\"\x00\x12\x66\n\x0fGetTransferCode\x12\'.mobilecoind_api.GetTransferCodeRequest\x1a(.mobilecoind_api.GetTransferCodeResponse\"\x00\x12\x66\n\x0fReadAddressCode\x12\'.mobilecoind_api.ReadAddressCodeRequest\x1a(.mobilecoind_api.ReadAddressCodeResponse\"\x00\x12\x63\n\x0eGetAddressCode\x12&.mobilecoind_api.GetAddressCodeRequest\x1a\'.mobilecoind_api.GetAddressCodeResponse\"\x00\x12W\n\nGenerateTx\x12\".mobilecoind_api.GenerateTxRequest\x1a#.mobilecoind_api.GenerateTxResponse\"\x00\x12{\n\x16GenerateOptimizationTx\x12..mobilecoind_api.GenerateOptimizationTxRequest\x1a/.mobilecoind_api.GenerateOptimizationTxResponse\"\x00\x12{\n\x16GenerateTransferCodeTx\x12..mobilecoind_api.GenerateTransferCodeTxRequest\x1a/.mobilecoind_api.GenerateTransferCodeTxResponse\"\x00\x12~\n\x17GenerateTxFromTxOutList\x12/.mobilecoind_api.GenerateTxFromTxOutListRequest\x1a\x30.mobilecoind_api.GenerateTxFromTxOutListResponse\"\x00\x12Q\n\x08SubmitTx\x12 .mobilecoind_api.SubmitTxRequest\x1a!.mobilecoind_api.SubmitTxResponse\"\x00\x12Q\n\rGetLedgerInfo\x12\x16.google.protobuf.Empty\x1a&.mobilecoind_api.GetLedgerInfoResponse\"\x00\x12]\n\x0cGetBlockInfo\x12$.mobilecoind_api.GetBlockInfoRequest\x1a%.mobilecoind_api.GetBlockInfoResponse\"\x00\x12Q\n\x08GetBlock\x12 .mobilecoind_api.GetBlockRequest\x1a!.mobilecoind_api.GetBlockResponse\"\x00\x12r\n\x13GetTxStatusAsSender\x12+.mobilecoind_api.GetTxStatusAsSenderRequest\x1a,.mobilecoind_api.GetTxStatusAsSenderResponse\"\x00\x12x\n\x15GetTxStatusAsReceiver\x12-.mobilecoind_api.GetTxStatusAsReceiverRequest\x1a..mobilecoind_api.GetTxStatusAsReceiverResponse\"\x00\x12l\n\x11GetProcessedBlock\x12).mobilecoind_api.GetProcessedBlockRequest\x1a*.mobilecoind_api.GetProcessedBlockResponse\"\x00\x12W\n\nGetBalance\x12\".mobilecoind_api.GetBalanceRequest\x1a#.mobilecoind_api.GetBalanceResponse\"\x00\x12Z\n\x0bSendPayment\x12#.mobilecoind_api.SendPaymentRequest\x1a$.mobilecoind_api.SendPaymentResponse\"\x00\x12W\n\x10GetNetworkStatus\x12\x16.google.protobuf.Empty\x1a).mobilecoind_api.GetNetworkStatusResponse\"\x00\x42,\n\x1a\x63om.mobilecoin.mobilecoindB\x0eMobileCoinDAPIb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,external__pb2.DESCRIPTOR,blockchain__pb2.DESCRIPTOR,])

_TXSTATUS = _descriptor.EnumDescriptor(
  name='TxStatus',
  full_name='mobilecoind_api.TxStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Unknown', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Verified', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TombstoneBlockExceeded', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidConfirmationNumber', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6203,
  serialized_end=6299,
)
_sym_db.RegisterEnumDescriptor(_TXSTATUS)

TxStatus = enum_type_wrapper.EnumTypeWrapper(_TXSTATUS)
_PROCESSEDTXOUTDIRECTION = _descriptor.EnumDescriptor(
  name='ProcessedTxOutDirection',
  full_name='mobilecoind_api.ProcessedTxOutDirection',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Invalid', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Received', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Spent', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6301,
  serialized_end=6364,
)
_sym_db.RegisterEnumDescriptor(_PROCESSEDTXOUTDIRECTION)

ProcessedTxOutDirection = enum_type_wrapper.EnumTypeWrapper(_PROCESSEDTXOUTDIRECTION)
Unknown = 0
Verified = 1
TombstoneBlockExceeded = 2
InvalidConfirmationNumber = 3
Invalid = 0
Received = 1
Spent = 2



_OUTLAY = _descriptor.Descriptor(
  name='Outlay',
  full_name='mobilecoind_api.Outlay',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='mobilecoind_api.Outlay.value', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='receiver', full_name='mobilecoind_api.Outlay.receiver', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=105,
  serialized_end=171,
)


_UNSPENTTXOUT = _descriptor.Descriptor(
  name='UnspentTxOut',
  full_name='mobilecoind_api.UnspentTxOut',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx_out', full_name='mobilecoind_api.UnspentTxOut.tx_out', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subaddress_index', full_name='mobilecoind_api.UnspentTxOut.subaddress_index', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key_image', full_name='mobilecoind_api.UnspentTxOut.key_image', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mobilecoind_api.UnspentTxOut.value', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attempted_spend_height', full_name='mobilecoind_api.UnspentTxOut.attempted_spend_height', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attempted_spend_tombstone', full_name='mobilecoind_api.UnspentTxOut.attempted_spend_tombstone', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='monitor_id', full_name='mobilecoind_api.UnspentTxOut.monitor_id', index=6,
      number=10, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=174,
  serialized_end=388,
)


_TXPROPOSAL_OUTLAYINDEXTOTXOUTINDEXENTRY = _descriptor.Descriptor(
  name='OutlayIndexToTxOutIndexEntry',
  full_name='mobilecoind_api.TxProposal.OutlayIndexToTxOutIndexEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='mobilecoind_api.TxProposal.OutlayIndexToTxOutIndexEntry.key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mobilecoind_api.TxProposal.OutlayIndexToTxOutIndexEntry.value', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=674,
  serialized_end=736,
)

_TXPROPOSAL = _descriptor.Descriptor(
  name='TxProposal',
  full_name='mobilecoind_api.TxProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='input_list', full_name='mobilecoind_api.TxProposal.input_list', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outlay_list', full_name='mobilecoind_api.TxProposal.outlay_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tx', full_name='mobilecoind_api.TxProposal.tx', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fee', full_name='mobilecoind_api.TxProposal.fee', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outlay_index_to_tx_out_index', full_name='mobilecoind_api.TxProposal.outlay_index_to_tx_out_index', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outlay_confirmation_numbers', full_name='mobilecoind_api.TxProposal.outlay_confirmation_numbers', index=5,
      number=6, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TXPROPOSAL_OUTLAYINDEXTOTXOUTINDEXENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=391,
  serialized_end=736,
)


_SENDERTXRECEIPT = _descriptor.Descriptor(
  name='SenderTxReceipt',
  full_name='mobilecoind_api.SenderTxReceipt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_image_list', full_name='mobilecoind_api.SenderTxReceipt.key_image_list', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tombstone', full_name='mobilecoind_api.SenderTxReceipt.tombstone', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=738,
  serialized_end=818,
)


_RECEIVERTXRECEIPT = _descriptor.Descriptor(
  name='ReceiverTxReceipt',
  full_name='mobilecoind_api.ReceiverTxReceipt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recipient', full_name='mobilecoind_api.ReceiverTxReceipt.recipient', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tx_public_key', full_name='mobilecoind_api.ReceiverTxReceipt.tx_public_key', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tx_out_hash', full_name='mobilecoind_api.ReceiverTxReceipt.tx_out_hash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tombstone', full_name='mobilecoind_api.ReceiverTxReceipt.tombstone', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='confirmation_number', full_name='mobilecoind_api.ReceiverTxReceipt.confirmation_number', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=821,
  serialized_end=1007,
)


_MONITORSTATUS = _descriptor.Descriptor(
  name='MonitorStatus',
  full_name='mobilecoind_api.MonitorStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_key', full_name='mobilecoind_api.MonitorStatus.account_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_subaddress', full_name='mobilecoind_api.MonitorStatus.first_subaddress', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_subaddresses', full_name='mobilecoind_api.MonitorStatus.num_subaddresses', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_block', full_name='mobilecoind_api.MonitorStatus.first_block', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_block', full_name='mobilecoind_api.MonitorStatus.next_block', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='mobilecoind_api.MonitorStatus.name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1010,
  serialized_end=1175,
)


_PROCESSEDTXOUT = _descriptor.Descriptor(
  name='ProcessedTxOut',
  full_name='mobilecoind_api.ProcessedTxOut',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='monitor_id', full_name='mobilecoind_api.ProcessedTxOut.monitor_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subaddress_index', full_name='mobilecoind_api.ProcessedTxOut.subaddress_index', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='public_key', full_name='mobilecoind_api.ProcessedTxOut.public_key', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key_image', full_name='mobilecoind_api.ProcessedTxOut.key_image', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mobilecoind_api.ProcessedTxOut.value', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direction', full_name='mobilecoind_api.ProcessedTxOut.direction', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='address_code', full_name='mobilecoind_api.ProcessedTxOut.address_code', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1178,
  serialized_end=1428,
)


_ADDMONITORREQUEST = _descriptor.Descriptor(
  name='AddMonitorRequest',
  full_name='mobilecoind_api.AddMonitorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_key', full_name='mobilecoind_api.AddMonitorRequest.account_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_subaddress', full_name='mobilecoind_api.AddMonitorRequest.first_subaddress', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_subaddresses', full_name='mobilecoind_api.AddMonitorRequest.num_subaddresses', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_block', full_name='mobilecoind_api.AddMonitorRequest.first_block', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='mobilecoind_api.AddMonitorRequest.name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1431,
  serialized_end=1580,
)


_ADDMONITORRESPONSE = _descriptor.Descriptor(
  name='AddMonitorResponse',
  full_name='mobilecoind_api.AddMonitorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='monitor_id', full_name='mobilecoind_api.AddMonitorResponse.monitor_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1582,
  serialized_end=1622,
)


_REMOVEMONITORREQUEST = _descriptor.Descriptor(
  name='RemoveMonitorRequest',
  full_name='mobilecoind_api.RemoveMonitorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='monitor_id', full_name='mobilecoind_api.RemoveMonitorRequest.monitor_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1624,
  serialized_end=1666,
)


_GETMONITORLISTRESPONSE = _descriptor.Descriptor(
  name='GetMonitorListResponse',
  full_name='mobilecoind_api.GetMonitorListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='monitor_id_list', full_name='mobilecoind_api.GetMonitorListResponse.monitor_id_list', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1668,
  serialized_end=1717,
)


_GETMONITORSTATUSREQUEST = _descriptor.Descriptor(
  name='GetMonitorStatusRequest',
  full_name='mobilecoind_api.GetMonitorStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='monitor_id', full_name='mobilecoind_api.GetMonitorStatusRequest.monitor_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1719,
  serialized_end=1764,
)


_GETMONITORSTATUSRESPONSE = _descriptor.Descriptor(
  name='GetMonitorStatusResponse',
  full_name='mobilecoind_api.GetMonitorStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='mobilecoind_api.GetMonitorStatusResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1766,
  serialized_end=1840,
)


_GETUNSPENTTXOUTLISTREQUEST = _descriptor.Descriptor(
  name='GetUnspentTxOutListRequest',
  full_name='mobilecoind_api.GetUnspentTxOutListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='monitor_id', full_name='mobilecoind_api.GetUnspentTxOutListRequest.monitor_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subaddress_index', full_name='mobilecoind_api.GetUnspentTxOutListRequest.subaddress_index', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1842,
  serialized_end=1916,
)


_GETUNSPENTTXOUTLISTRESPONSE = _descriptor.Descriptor(
  name='GetUnspentTxOutListResponse',
  full_name='mobilecoind_api.GetUnspentTxOutListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='output_list', full_name='mobilecoind_api.GetUnspentTxOutListResponse.output_list', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1918,
  serialized_end=1999,
)


_GENERATEENTROPYRESPONSE = _descriptor.Descriptor(
  name='GenerateEntropyResponse',
  full_name='mobilecoind_api.GenerateEntropyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entropy', full_name='mobilecoind_api.GenerateEntropyResponse.entropy', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2001,
  serialized_end=2043,
)


_GETACCOUNTKEYREQUEST = _descriptor.Descriptor(
  name='GetAccountKeyRequest',
  full_name='mobilecoind_api.GetAccountKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entropy', full_name='mobilecoind_api.GetAccountKeyRequest.entropy', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2045,
  serialized_end=2084,
)


_GETACCOUNTKEYRESPONSE = _descriptor.Descriptor(
  name='GetAccountKeyResponse',
  full_name='mobilecoind_api.GetAccountKeyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_key', full_name='mobilecoind_api.GetAccountKeyResponse.account_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2086,
  serialized_end=2152,
)


_GETPUBLICADDRESSREQUEST = _descriptor.Descriptor(
  name='GetPublicAddressRequest',
  full_name='mobilecoind_api.GetPublicAddressRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='monitor_id', full_name='mobilecoind_api.GetPublicAddressRequest.monitor_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subaddress_index', full_name='mobilecoind_api.GetPublicAddressRequest.subaddress_index', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2154,
  serialized_end=2225,
)


_GETPUBLICADDRESSRESPONSE = _descriptor.Descriptor(
  name='GetPublicAddressResponse',
  full_name='mobilecoind_api.GetPublicAddressResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='public_address', full_name='mobilecoind_api.GetPublicAddressResponse.public_address', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2227,
  serialized_end=2302,
)


_READREQUESTCODEREQUEST = _descriptor.Descriptor(
  name='ReadRequestCodeRequest',
  full_name='mobilecoind_api.ReadRequestCodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='b58_code', full_name='mobilecoind_api.ReadRequestCodeRequest.b58_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2304,
  serialized_end=2346,
)


_READREQUESTCODERESPONSE = _descriptor.Descriptor(
  name='ReadRequestCodeResponse',
  full_name='mobilecoind_api.ReadRequestCodeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='receiver', full_name='mobilecoind_api.ReadRequestCodeResponse.receiver', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mobilecoind_api.ReadRequestCodeResponse.value', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='memo', full_name='mobilecoind_api.ReadRequestCodeResponse.memo', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2348,
  serialized_end=2445,
)


_GETREQUESTCODEREQUEST = _descriptor.Descriptor(
  name='GetRequestCodeRequest',
  full_name='mobilecoind_api.GetRequestCodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='receiver', full_name='mobilecoind_api.GetRequestCodeRequest.receiver', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mobilecoind_api.GetRequestCodeRequest.value', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='memo', full_name='mobilecoind_api.GetRequestCodeRequest.memo', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2447,
  serialized_end=2542,
)


_GETREQUESTCODERESPONSE = _descriptor.Descriptor(
  name='GetRequestCodeResponse',
  full_name='mobilecoind_api.GetRequestCodeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='b58_code', full_name='mobilecoind_api.GetRequestCodeResponse.b58_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2544,
  serialized_end=2586,
)


_READTRANSFERCODEREQUEST = _descriptor.Descriptor(
  name='ReadTransferCodeRequest',
  full_name='mobilecoind_api.ReadTransferCodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='b58_code', full_name='mobilecoind_api.ReadTransferCodeRequest.b58_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2588,
  serialized_end=2631,
)


_READTRANSFERCODERESPONSE = _descriptor.Descriptor(
  name='ReadTransferCodeResponse',
  full_name='mobilecoind_api.ReadTransferCodeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entropy', full_name='mobilecoind_api.ReadTransferCodeResponse.entropy', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tx_public_key', full_name='mobilecoind_api.ReadTransferCodeResponse.tx_public_key', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='memo', full_name='mobilecoind_api.ReadTransferCodeResponse.memo', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='utxo', full_name='mobilecoind_api.ReadTransferCodeResponse.utxo', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2634,
  serialized_end=2790,
)


_GETTRANSFERCODEREQUEST = _descriptor.Descriptor(
  name='GetTransferCodeRequest',
  full_name='mobilecoind_api.GetTransferCodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entropy', full_name='mobilecoind_api.GetTransferCodeRequest.entropy', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tx_public_key', full_name='mobilecoind_api.GetTransferCodeRequest.tx_public_key', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='memo', full_name='mobilecoind_api.GetTransferCodeRequest.memo', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2792,
  serialized_end=2901,
)


_GETTRANSFERCODERESPONSE = _descriptor.Descriptor(
  name='GetTransferCodeResponse',
  full_name='mobilecoind_api.GetTransferCodeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='b58_code', full_name='mobilecoind_api.GetTransferCodeResponse.b58_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2903,
  serialized_end=2946,
)


_READADDRESSCODEREQUEST = _descriptor.Descriptor(
  name='ReadAddressCodeRequest',
  full_name='mobilecoind_api.ReadAddressCodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='b58_code', full_name='mobilecoind_api.ReadAddressCodeRequest.b58_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2948,
  serialized_end=2990,
)


_READADDRESSCODERESPONSE = _descriptor.Descriptor(
  name='ReadAddressCodeResponse',
  full_name='mobilecoind_api.ReadAddressCodeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='receiver', full_name='mobilecoind_api.ReadAddressCodeResponse.receiver', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2992,
  serialized_end=3060,
)


_GETADDRESSCODEREQUEST = _descriptor.Descriptor(
  name='GetAddressCodeRequest',
  full_name='mobilecoind_api.GetAddressCodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='receiver', full_name='mobilecoind_api.GetAddressCodeRequest.receiver', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3062,
  serialized_end=3128,
)


_GETADDRESSCODERESPONSE = _descriptor.Descriptor(
  name='GetAddressCodeResponse',
  full_name='mobilecoind_api.GetAddressCodeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='b58_code', full_name='mobilecoind_api.GetAddressCodeResponse.b58_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3130,
  serialized_end=3172,
)


_GENERATETXREQUEST = _descriptor.Descriptor(
  name='GenerateTxRequest',
  full_name='mobilecoind_api.GenerateTxRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender_monitor_id', full_name='mobilecoind_api.GenerateTxRequest.sender_monitor_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_subaddress', full_name='mobilecoind_api.GenerateTxRequest.change_subaddress', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input_list', full_name='mobilecoind_api.GenerateTxRequest.input_list', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outlay_list', full_name='mobilecoind_api.GenerateTxRequest.outlay_list', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fee', full_name='mobilecoind_api.GenerateTxRequest.fee', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tombstone', full_name='mobilecoind_api.GenerateTxRequest.tombstone', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3175,
  serialized_end=3377,
)


_GENERATETXRESPONSE = _descriptor.Descriptor(
  name='GenerateTxResponse',
  full_name='mobilecoind_api.GenerateTxResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx_proposal', full_name='mobilecoind_api.GenerateTxResponse.tx_proposal', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3379,
  serialized_end=3449,
)


_GENERATEOPTIMIZATIONTXREQUEST = _descriptor.Descriptor(
  name='GenerateOptimizationTxRequest',
  full_name='mobilecoind_api.GenerateOptimizationTxRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='monitor_id', full_name='mobilecoind_api.GenerateOptimizationTxRequest.monitor_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subaddress', full_name='mobilecoind_api.GenerateOptimizationTxRequest.subaddress', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3451,
  serialized_end=3522,
)


_GENERATEOPTIMIZATIONTXRESPONSE = _descriptor.Descriptor(
  name='GenerateOptimizationTxResponse',
  full_name='mobilecoind_api.GenerateOptimizationTxResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx_proposal', full_name='mobilecoind_api.GenerateOptimizationTxResponse.tx_proposal', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3524,
  serialized_end=3606,
)


_GENERATETRANSFERCODETXREQUEST = _descriptor.Descriptor(
  name='GenerateTransferCodeTxRequest',
  full_name='mobilecoind_api.GenerateTransferCodeTxRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender_monitor_id', full_name='mobilecoind_api.GenerateTransferCodeTxRequest.sender_monitor_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_subaddress', full_name='mobilecoind_api.GenerateTransferCodeTxRequest.change_subaddress', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input_list', full_name='mobilecoind_api.GenerateTransferCodeTxRequest.input_list', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mobilecoind_api.GenerateTransferCodeTxRequest.value', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fee', full_name='mobilecoind_api.GenerateTransferCodeTxRequest.fee', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tombstone', full_name='mobilecoind_api.GenerateTransferCodeTxRequest.tombstone', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='memo', full_name='mobilecoind_api.GenerateTransferCodeTxRequest.memo', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3609,
  serialized_end=3806,
)


_GENERATETRANSFERCODETXRESPONSE = _descriptor.Descriptor(
  name='GenerateTransferCodeTxResponse',
  full_name='mobilecoind_api.GenerateTransferCodeTxResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx_proposal', full_name='mobilecoind_api.GenerateTransferCodeTxResponse.tx_proposal', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entropy', full_name='mobilecoind_api.GenerateTransferCodeTxResponse.entropy', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tx_public_key', full_name='mobilecoind_api.GenerateTransferCodeTxResponse.tx_public_key', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='memo', full_name='mobilecoind_api.GenerateTransferCodeTxResponse.memo', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='b58_code', full_name='mobilecoind_api.GenerateTransferCodeTxResponse.b58_code', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3809,
  serialized_end=3994,
)


_GENERATETXFROMTXOUTLISTREQUEST = _descriptor.Descriptor(
  name='GenerateTxFromTxOutListRequest',
  full_name='mobilecoind_api.GenerateTxFromTxOutListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_key', full_name='mobilecoind_api.GenerateTxFromTxOutListRequest.account_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input_list', full_name='mobilecoind_api.GenerateTxFromTxOutListRequest.input_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='receiver', full_name='mobilecoind_api.GenerateTxFromTxOutListRequest.receiver', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fee', full_name='mobilecoind_api.GenerateTxFromTxOutListRequest.fee', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3997,
  serialized_end=4179,
)


_GENERATETXFROMTXOUTLISTRESPONSE = _descriptor.Descriptor(
  name='GenerateTxFromTxOutListResponse',
  full_name='mobilecoind_api.GenerateTxFromTxOutListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx_proposal', full_name='mobilecoind_api.GenerateTxFromTxOutListResponse.tx_proposal', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4181,
  serialized_end=4264,
)


_SUBMITTXREQUEST = _descriptor.Descriptor(
  name='SubmitTxRequest',
  full_name='mobilecoind_api.SubmitTxRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx_proposal', full_name='mobilecoind_api.SubmitTxRequest.tx_proposal', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4266,
  serialized_end=4333,
)


_SUBMITTXRESPONSE = _descriptor.Descriptor(
  name='SubmitTxResponse',
  full_name='mobilecoind_api.SubmitTxResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender_tx_receipt', full_name='mobilecoind_api.SubmitTxResponse.sender_tx_receipt', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='receiver_tx_receipt_list', full_name='mobilecoind_api.SubmitTxResponse.receiver_tx_receipt_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4336,
  serialized_end=4485,
)


_GETLEDGERINFORESPONSE = _descriptor.Descriptor(
  name='GetLedgerInfoResponse',
  full_name='mobilecoind_api.GetLedgerInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_count', full_name='mobilecoind_api.GetLedgerInfoResponse.block_count', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='txo_count', full_name='mobilecoind_api.GetLedgerInfoResponse.txo_count', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4487,
  serialized_end=4550,
)


_GETBLOCKINFOREQUEST = _descriptor.Descriptor(
  name='GetBlockInfoRequest',
  full_name='mobilecoind_api.GetBlockInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='mobilecoind_api.GetBlockInfoRequest.block', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4552,
  serialized_end=4588,
)


_GETBLOCKINFORESPONSE = _descriptor.Descriptor(
  name='GetBlockInfoResponse',
  full_name='mobilecoind_api.GetBlockInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_image_count', full_name='mobilecoind_api.GetBlockInfoResponse.key_image_count', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='txo_count', full_name='mobilecoind_api.GetBlockInfoResponse.txo_count', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4590,
  serialized_end=4656,
)


_ARCHIVEBLOCKSIGNATUREDATA = _descriptor.Descriptor(
  name='ArchiveBlockSignatureData',
  full_name='mobilecoind_api.ArchiveBlockSignatureData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src_url', full_name='mobilecoind_api.ArchiveBlockSignatureData.src_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filename', full_name='mobilecoind_api.ArchiveBlockSignatureData.filename', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signature', full_name='mobilecoind_api.ArchiveBlockSignatureData.signature', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4658,
  serialized_end=4767,
)


_GETBLOCKREQUEST = _descriptor.Descriptor(
  name='GetBlockRequest',
  full_name='mobilecoind_api.GetBlockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='mobilecoind_api.GetBlockRequest.block', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4769,
  serialized_end=4801,
)


_GETBLOCKRESPONSE = _descriptor.Descriptor(
  name='GetBlockResponse',
  full_name='mobilecoind_api.GetBlockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='mobilecoind_api.GetBlockResponse.block', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signatures', full_name='mobilecoind_api.GetBlockResponse.signatures', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key_images', full_name='mobilecoind_api.GetBlockResponse.key_images', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='txos', full_name='mobilecoind_api.GetBlockResponse.txos', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4804,
  serialized_end=4991,
)


_GETTXSTATUSASSENDERREQUEST = _descriptor.Descriptor(
  name='GetTxStatusAsSenderRequest',
  full_name='mobilecoind_api.GetTxStatusAsSenderRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='receipt', full_name='mobilecoind_api.GetTxStatusAsSenderRequest.receipt', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4993,
  serialized_end=5072,
)


_GETTXSTATUSASSENDERRESPONSE = _descriptor.Descriptor(
  name='GetTxStatusAsSenderResponse',
  full_name='mobilecoind_api.GetTxStatusAsSenderResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='mobilecoind_api.GetTxStatusAsSenderResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5074,
  serialized_end=5146,
)


_GETTXSTATUSASRECEIVERREQUEST = _descriptor.Descriptor(
  name='GetTxStatusAsReceiverRequest',
  full_name='mobilecoind_api.GetTxStatusAsReceiverRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='receipt', full_name='mobilecoind_api.GetTxStatusAsReceiverRequest.receipt', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='monitor_id', full_name='mobilecoind_api.GetTxStatusAsReceiverRequest.monitor_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5148,
  serialized_end=5251,
)


_GETTXSTATUSASRECEIVERRESPONSE = _descriptor.Descriptor(
  name='GetTxStatusAsReceiverResponse',
  full_name='mobilecoind_api.GetTxStatusAsReceiverResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='mobilecoind_api.GetTxStatusAsReceiverResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5253,
  serialized_end=5327,
)


_GETPROCESSEDBLOCKREQUEST = _descriptor.Descriptor(
  name='GetProcessedBlockRequest',
  full_name='mobilecoind_api.GetProcessedBlockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='monitor_id', full_name='mobilecoind_api.GetProcessedBlockRequest.monitor_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block', full_name='mobilecoind_api.GetProcessedBlockRequest.block', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5329,
  serialized_end=5390,
)


_GETPROCESSEDBLOCKRESPONSE = _descriptor.Descriptor(
  name='GetProcessedBlockResponse',
  full_name='mobilecoind_api.GetProcessedBlockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx_outs', full_name='mobilecoind_api.GetProcessedBlockResponse.tx_outs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5392,
  serialized_end=5469,
)


_GETBALANCEREQUEST = _descriptor.Descriptor(
  name='GetBalanceRequest',
  full_name='mobilecoind_api.GetBalanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='monitor_id', full_name='mobilecoind_api.GetBalanceRequest.monitor_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subaddress_index', full_name='mobilecoind_api.GetBalanceRequest.subaddress_index', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5471,
  serialized_end=5536,
)


_GETBALANCERESPONSE = _descriptor.Descriptor(
  name='GetBalanceResponse',
  full_name='mobilecoind_api.GetBalanceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='balance', full_name='mobilecoind_api.GetBalanceResponse.balance', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5538,
  serialized_end=5575,
)


_SENDPAYMENTREQUEST = _descriptor.Descriptor(
  name='SendPaymentRequest',
  full_name='mobilecoind_api.SendPaymentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender_monitor_id', full_name='mobilecoind_api.SendPaymentRequest.sender_monitor_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sender_subaddress', full_name='mobilecoind_api.SendPaymentRequest.sender_subaddress', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outlay_list', full_name='mobilecoind_api.SendPaymentRequest.outlay_list', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fee', full_name='mobilecoind_api.SendPaymentRequest.fee', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tombstone', full_name='mobilecoind_api.SendPaymentRequest.tombstone', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5578,
  serialized_end=5730,
)


_SENDPAYMENTRESPONSE = _descriptor.Descriptor(
  name='SendPaymentResponse',
  full_name='mobilecoind_api.SendPaymentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender_tx_receipt', full_name='mobilecoind_api.SendPaymentResponse.sender_tx_receipt', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='receiver_tx_receipt_list', full_name='mobilecoind_api.SendPaymentResponse.receiver_tx_receipt_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tx_proposal', full_name='mobilecoind_api.SendPaymentResponse.tx_proposal', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5733,
  serialized_end=5935,
)


_GETNETWORKSTATUSRESPONSE_PEERBLOCKINDEXMAPENTRY = _descriptor.Descriptor(
  name='PeerBlockIndexMapEntry',
  full_name='mobilecoind_api.GetNetworkStatusResponse.PeerBlockIndexMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='mobilecoind_api.GetNetworkStatusResponse.PeerBlockIndexMapEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mobilecoind_api.GetNetworkStatusResponse.PeerBlockIndexMapEntry.value', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6145,
  serialized_end=6201,
)

_GETNETWORKSTATUSRESPONSE = _descriptor.Descriptor(
  name='GetNetworkStatusResponse',
  full_name='mobilecoind_api.GetNetworkStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='network_highest_block_index', full_name='mobilecoind_api.GetNetworkStatusResponse.network_highest_block_index', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peer_block_index_map', full_name='mobilecoind_api.GetNetworkStatusResponse.peer_block_index_map', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_block_index', full_name='mobilecoind_api.GetNetworkStatusResponse.local_block_index', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_behind', full_name='mobilecoind_api.GetNetworkStatusResponse.is_behind', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GETNETWORKSTATUSRESPONSE_PEERBLOCKINDEXMAPENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5938,
  serialized_end=6201,
)

_OUTLAY.fields_by_name['receiver'].message_type = external__pb2._PUBLICADDRESS
_UNSPENTTXOUT.fields_by_name['tx_out'].message_type = external__pb2._TXOUT
_UNSPENTTXOUT.fields_by_name['key_image'].message_type = external__pb2._KEYIMAGE
_TXPROPOSAL_OUTLAYINDEXTOTXOUTINDEXENTRY.containing_type = _TXPROPOSAL
_TXPROPOSAL.fields_by_name['input_list'].message_type = _UNSPENTTXOUT
_TXPROPOSAL.fields_by_name['outlay_list'].message_type = _OUTLAY
_TXPROPOSAL.fields_by_name['tx'].message_type = external__pb2._TX
_TXPROPOSAL.fields_by_name['outlay_index_to_tx_out_index'].message_type = _TXPROPOSAL_OUTLAYINDEXTOTXOUTINDEXENTRY
_SENDERTXRECEIPT.fields_by_name['key_image_list'].message_type = external__pb2._KEYIMAGE
_RECEIVERTXRECEIPT.fields_by_name['recipient'].message_type = external__pb2._PUBLICADDRESS
_RECEIVERTXRECEIPT.fields_by_name['tx_public_key'].message_type = external__pb2._COMPRESSEDRISTRETTO
_MONITORSTATUS.fields_by_name['account_key'].message_type = external__pb2._ACCOUNTKEY
_PROCESSEDTXOUT.fields_by_name['public_key'].message_type = external__pb2._COMPRESSEDRISTRETTO
_PROCESSEDTXOUT.fields_by_name['key_image'].message_type = external__pb2._KEYIMAGE
_PROCESSEDTXOUT.fields_by_name['direction'].enum_type = _PROCESSEDTXOUTDIRECTION
_ADDMONITORREQUEST.fields_by_name['account_key'].message_type = external__pb2._ACCOUNTKEY
_GETMONITORSTATUSRESPONSE.fields_by_name['status'].message_type = _MONITORSTATUS
_GETUNSPENTTXOUTLISTRESPONSE.fields_by_name['output_list'].message_type = _UNSPENTTXOUT
_GETACCOUNTKEYRESPONSE.fields_by_name['account_key'].message_type = external__pb2._ACCOUNTKEY
_GETPUBLICADDRESSRESPONSE.fields_by_name['public_address'].message_type = external__pb2._PUBLICADDRESS
_READREQUESTCODERESPONSE.fields_by_name['receiver'].message_type = external__pb2._PUBLICADDRESS
_GETREQUESTCODEREQUEST.fields_by_name['receiver'].message_type = external__pb2._PUBLICADDRESS
_READTRANSFERCODERESPONSE.fields_by_name['tx_public_key'].message_type = external__pb2._COMPRESSEDRISTRETTO
_READTRANSFERCODERESPONSE.fields_by_name['utxo'].message_type = _UNSPENTTXOUT
_GETTRANSFERCODEREQUEST.fields_by_name['tx_public_key'].message_type = external__pb2._COMPRESSEDRISTRETTO
_READADDRESSCODERESPONSE.fields_by_name['receiver'].message_type = external__pb2._PUBLICADDRESS
_GETADDRESSCODEREQUEST.fields_by_name['receiver'].message_type = external__pb2._PUBLICADDRESS
_GENERATETXREQUEST.fields_by_name['input_list'].message_type = _UNSPENTTXOUT
_GENERATETXREQUEST.fields_by_name['outlay_list'].message_type = _OUTLAY
_GENERATETXRESPONSE.fields_by_name['tx_proposal'].message_type = _TXPROPOSAL
_GENERATEOPTIMIZATIONTXRESPONSE.fields_by_name['tx_proposal'].message_type = _TXPROPOSAL
_GENERATETRANSFERCODETXREQUEST.fields_by_name['input_list'].message_type = _UNSPENTTXOUT
_GENERATETRANSFERCODETXRESPONSE.fields_by_name['tx_proposal'].message_type = _TXPROPOSAL
_GENERATETRANSFERCODETXRESPONSE.fields_by_name['tx_public_key'].message_type = external__pb2._COMPRESSEDRISTRETTO
_GENERATETXFROMTXOUTLISTREQUEST.fields_by_name['account_key'].message_type = external__pb2._ACCOUNTKEY
_GENERATETXFROMTXOUTLISTREQUEST.fields_by_name['input_list'].message_type = _UNSPENTTXOUT
_GENERATETXFROMTXOUTLISTREQUEST.fields_by_name['receiver'].message_type = external__pb2._PUBLICADDRESS
_GENERATETXFROMTXOUTLISTRESPONSE.fields_by_name['tx_proposal'].message_type = _TXPROPOSAL
_SUBMITTXREQUEST.fields_by_name['tx_proposal'].message_type = _TXPROPOSAL
_SUBMITTXRESPONSE.fields_by_name['sender_tx_receipt'].message_type = _SENDERTXRECEIPT
_SUBMITTXRESPONSE.fields_by_name['receiver_tx_receipt_list'].message_type = _RECEIVERTXRECEIPT
_ARCHIVEBLOCKSIGNATUREDATA.fields_by_name['signature'].message_type = blockchain__pb2._BLOCKSIGNATURE
_GETBLOCKRESPONSE.fields_by_name['block'].message_type = blockchain__pb2._BLOCK
_GETBLOCKRESPONSE.fields_by_name['signatures'].message_type = _ARCHIVEBLOCKSIGNATUREDATA
_GETBLOCKRESPONSE.fields_by_name['key_images'].message_type = external__pb2._KEYIMAGE
_GETBLOCKRESPONSE.fields_by_name['txos'].message_type = external__pb2._TXOUT
_GETTXSTATUSASSENDERREQUEST.fields_by_name['receipt'].message_type = _SENDERTXRECEIPT
_GETTXSTATUSASSENDERRESPONSE.fields_by_name['status'].enum_type = _TXSTATUS
_GETTXSTATUSASRECEIVERREQUEST.fields_by_name['receipt'].message_type = _RECEIVERTXRECEIPT
_GETTXSTATUSASRECEIVERRESPONSE.fields_by_name['status'].enum_type = _TXSTATUS
_GETPROCESSEDBLOCKRESPONSE.fields_by_name['tx_outs'].message_type = _PROCESSEDTXOUT
_SENDPAYMENTREQUEST.fields_by_name['outlay_list'].message_type = _OUTLAY
_SENDPAYMENTRESPONSE.fields_by_name['sender_tx_receipt'].message_type = _SENDERTXRECEIPT
_SENDPAYMENTRESPONSE.fields_by_name['receiver_tx_receipt_list'].message_type = _RECEIVERTXRECEIPT
_SENDPAYMENTRESPONSE.fields_by_name['tx_proposal'].message_type = _TXPROPOSAL
_GETNETWORKSTATUSRESPONSE_PEERBLOCKINDEXMAPENTRY.containing_type = _GETNETWORKSTATUSRESPONSE
_GETNETWORKSTATUSRESPONSE.fields_by_name['peer_block_index_map'].message_type = _GETNETWORKSTATUSRESPONSE_PEERBLOCKINDEXMAPENTRY
DESCRIPTOR.message_types_by_name['Outlay'] = _OUTLAY
DESCRIPTOR.message_types_by_name['UnspentTxOut'] = _UNSPENTTXOUT
DESCRIPTOR.message_types_by_name['TxProposal'] = _TXPROPOSAL
DESCRIPTOR.message_types_by_name['SenderTxReceipt'] = _SENDERTXRECEIPT
DESCRIPTOR.message_types_by_name['ReceiverTxReceipt'] = _RECEIVERTXRECEIPT
DESCRIPTOR.message_types_by_name['MonitorStatus'] = _MONITORSTATUS
DESCRIPTOR.message_types_by_name['ProcessedTxOut'] = _PROCESSEDTXOUT
DESCRIPTOR.message_types_by_name['AddMonitorRequest'] = _ADDMONITORREQUEST
DESCRIPTOR.message_types_by_name['AddMonitorResponse'] = _ADDMONITORRESPONSE
DESCRIPTOR.message_types_by_name['RemoveMonitorRequest'] = _REMOVEMONITORREQUEST
DESCRIPTOR.message_types_by_name['GetMonitorListResponse'] = _GETMONITORLISTRESPONSE
DESCRIPTOR.message_types_by_name['GetMonitorStatusRequest'] = _GETMONITORSTATUSREQUEST
DESCRIPTOR.message_types_by_name['GetMonitorStatusResponse'] = _GETMONITORSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['GetUnspentTxOutListRequest'] = _GETUNSPENTTXOUTLISTREQUEST
DESCRIPTOR.message_types_by_name['GetUnspentTxOutListResponse'] = _GETUNSPENTTXOUTLISTRESPONSE
DESCRIPTOR.message_types_by_name['GenerateEntropyResponse'] = _GENERATEENTROPYRESPONSE
DESCRIPTOR.message_types_by_name['GetAccountKeyRequest'] = _GETACCOUNTKEYREQUEST
DESCRIPTOR.message_types_by_name['GetAccountKeyResponse'] = _GETACCOUNTKEYRESPONSE
DESCRIPTOR.message_types_by_name['GetPublicAddressRequest'] = _GETPUBLICADDRESSREQUEST
DESCRIPTOR.message_types_by_name['GetPublicAddressResponse'] = _GETPUBLICADDRESSRESPONSE
DESCRIPTOR.message_types_by_name['ReadRequestCodeRequest'] = _READREQUESTCODEREQUEST
DESCRIPTOR.message_types_by_name['ReadRequestCodeResponse'] = _READREQUESTCODERESPONSE
DESCRIPTOR.message_types_by_name['GetRequestCodeRequest'] = _GETREQUESTCODEREQUEST
DESCRIPTOR.message_types_by_name['GetRequestCodeResponse'] = _GETREQUESTCODERESPONSE
DESCRIPTOR.message_types_by_name['ReadTransferCodeRequest'] = _READTRANSFERCODEREQUEST
DESCRIPTOR.message_types_by_name['ReadTransferCodeResponse'] = _READTRANSFERCODERESPONSE
DESCRIPTOR.message_types_by_name['GetTransferCodeRequest'] = _GETTRANSFERCODEREQUEST
DESCRIPTOR.message_types_by_name['GetTransferCodeResponse'] = _GETTRANSFERCODERESPONSE
DESCRIPTOR.message_types_by_name['ReadAddressCodeRequest'] = _READADDRESSCODEREQUEST
DESCRIPTOR.message_types_by_name['ReadAddressCodeResponse'] = _READADDRESSCODERESPONSE
DESCRIPTOR.message_types_by_name['GetAddressCodeRequest'] = _GETADDRESSCODEREQUEST
DESCRIPTOR.message_types_by_name['GetAddressCodeResponse'] = _GETADDRESSCODERESPONSE
DESCRIPTOR.message_types_by_name['GenerateTxRequest'] = _GENERATETXREQUEST
DESCRIPTOR.message_types_by_name['GenerateTxResponse'] = _GENERATETXRESPONSE
DESCRIPTOR.message_types_by_name['GenerateOptimizationTxRequest'] = _GENERATEOPTIMIZATIONTXREQUEST
DESCRIPTOR.message_types_by_name['GenerateOptimizationTxResponse'] = _GENERATEOPTIMIZATIONTXRESPONSE
DESCRIPTOR.message_types_by_name['GenerateTransferCodeTxRequest'] = _GENERATETRANSFERCODETXREQUEST
DESCRIPTOR.message_types_by_name['GenerateTransferCodeTxResponse'] = _GENERATETRANSFERCODETXRESPONSE
DESCRIPTOR.message_types_by_name['GenerateTxFromTxOutListRequest'] = _GENERATETXFROMTXOUTLISTREQUEST
DESCRIPTOR.message_types_by_name['GenerateTxFromTxOutListResponse'] = _GENERATETXFROMTXOUTLISTRESPONSE
DESCRIPTOR.message_types_by_name['SubmitTxRequest'] = _SUBMITTXREQUEST
DESCRIPTOR.message_types_by_name['SubmitTxResponse'] = _SUBMITTXRESPONSE
DESCRIPTOR.message_types_by_name['GetLedgerInfoResponse'] = _GETLEDGERINFORESPONSE
DESCRIPTOR.message_types_by_name['GetBlockInfoRequest'] = _GETBLOCKINFOREQUEST
DESCRIPTOR.message_types_by_name['GetBlockInfoResponse'] = _GETBLOCKINFORESPONSE
DESCRIPTOR.message_types_by_name['ArchiveBlockSignatureData'] = _ARCHIVEBLOCKSIGNATUREDATA
DESCRIPTOR.message_types_by_name['GetBlockRequest'] = _GETBLOCKREQUEST
DESCRIPTOR.message_types_by_name['GetBlockResponse'] = _GETBLOCKRESPONSE
DESCRIPTOR.message_types_by_name['GetTxStatusAsSenderRequest'] = _GETTXSTATUSASSENDERREQUEST
DESCRIPTOR.message_types_by_name['GetTxStatusAsSenderResponse'] = _GETTXSTATUSASSENDERRESPONSE
DESCRIPTOR.message_types_by_name['GetTxStatusAsReceiverRequest'] = _GETTXSTATUSASRECEIVERREQUEST
DESCRIPTOR.message_types_by_name['GetTxStatusAsReceiverResponse'] = _GETTXSTATUSASRECEIVERRESPONSE
DESCRIPTOR.message_types_by_name['GetProcessedBlockRequest'] = _GETPROCESSEDBLOCKREQUEST
DESCRIPTOR.message_types_by_name['GetProcessedBlockResponse'] = _GETPROCESSEDBLOCKRESPONSE
DESCRIPTOR.message_types_by_name['GetBalanceRequest'] = _GETBALANCEREQUEST
DESCRIPTOR.message_types_by_name['GetBalanceResponse'] = _GETBALANCERESPONSE
DESCRIPTOR.message_types_by_name['SendPaymentRequest'] = _SENDPAYMENTREQUEST
DESCRIPTOR.message_types_by_name['SendPaymentResponse'] = _SENDPAYMENTRESPONSE
DESCRIPTOR.message_types_by_name['GetNetworkStatusResponse'] = _GETNETWORKSTATUSRESPONSE
DESCRIPTOR.enum_types_by_name['TxStatus'] = _TXSTATUS
DESCRIPTOR.enum_types_by_name['ProcessedTxOutDirection'] = _PROCESSEDTXOUTDIRECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Outlay = _reflection.GeneratedProtocolMessageType('Outlay', (_message.Message,), {
  'DESCRIPTOR' : _OUTLAY,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.Outlay)
  })
_sym_db.RegisterMessage(Outlay)

UnspentTxOut = _reflection.GeneratedProtocolMessageType('UnspentTxOut', (_message.Message,), {
  'DESCRIPTOR' : _UNSPENTTXOUT,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.UnspentTxOut)
  })
_sym_db.RegisterMessage(UnspentTxOut)

TxProposal = _reflection.GeneratedProtocolMessageType('TxProposal', (_message.Message,), {

  'OutlayIndexToTxOutIndexEntry' : _reflection.GeneratedProtocolMessageType('OutlayIndexToTxOutIndexEntry', (_message.Message,), {
    'DESCRIPTOR' : _TXPROPOSAL_OUTLAYINDEXTOTXOUTINDEXENTRY,
    '__module__' : 'mobilecoind_api_pb2'
    # @@protoc_insertion_point(class_scope:mobilecoind_api.TxProposal.OutlayIndexToTxOutIndexEntry)
    })
  ,
  'DESCRIPTOR' : _TXPROPOSAL,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.TxProposal)
  })
_sym_db.RegisterMessage(TxProposal)
_sym_db.RegisterMessage(TxProposal.OutlayIndexToTxOutIndexEntry)

SenderTxReceipt = _reflection.GeneratedProtocolMessageType('SenderTxReceipt', (_message.Message,), {
  'DESCRIPTOR' : _SENDERTXRECEIPT,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.SenderTxReceipt)
  })
_sym_db.RegisterMessage(SenderTxReceipt)

ReceiverTxReceipt = _reflection.GeneratedProtocolMessageType('ReceiverTxReceipt', (_message.Message,), {
  'DESCRIPTOR' : _RECEIVERTXRECEIPT,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.ReceiverTxReceipt)
  })
_sym_db.RegisterMessage(ReceiverTxReceipt)

MonitorStatus = _reflection.GeneratedProtocolMessageType('MonitorStatus', (_message.Message,), {
  'DESCRIPTOR' : _MONITORSTATUS,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.MonitorStatus)
  })
_sym_db.RegisterMessage(MonitorStatus)

ProcessedTxOut = _reflection.GeneratedProtocolMessageType('ProcessedTxOut', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSEDTXOUT,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.ProcessedTxOut)
  })
_sym_db.RegisterMessage(ProcessedTxOut)

AddMonitorRequest = _reflection.GeneratedProtocolMessageType('AddMonitorRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDMONITORREQUEST,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.AddMonitorRequest)
  })
_sym_db.RegisterMessage(AddMonitorRequest)

AddMonitorResponse = _reflection.GeneratedProtocolMessageType('AddMonitorResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDMONITORRESPONSE,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.AddMonitorResponse)
  })
_sym_db.RegisterMessage(AddMonitorResponse)

RemoveMonitorRequest = _reflection.GeneratedProtocolMessageType('RemoveMonitorRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEMONITORREQUEST,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.RemoveMonitorRequest)
  })
_sym_db.RegisterMessage(RemoveMonitorRequest)

GetMonitorListResponse = _reflection.GeneratedProtocolMessageType('GetMonitorListResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMONITORLISTRESPONSE,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GetMonitorListResponse)
  })
_sym_db.RegisterMessage(GetMonitorListResponse)

GetMonitorStatusRequest = _reflection.GeneratedProtocolMessageType('GetMonitorStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMONITORSTATUSREQUEST,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GetMonitorStatusRequest)
  })
_sym_db.RegisterMessage(GetMonitorStatusRequest)

GetMonitorStatusResponse = _reflection.GeneratedProtocolMessageType('GetMonitorStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMONITORSTATUSRESPONSE,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GetMonitorStatusResponse)
  })
_sym_db.RegisterMessage(GetMonitorStatusResponse)

GetUnspentTxOutListRequest = _reflection.GeneratedProtocolMessageType('GetUnspentTxOutListRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUNSPENTTXOUTLISTREQUEST,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GetUnspentTxOutListRequest)
  })
_sym_db.RegisterMessage(GetUnspentTxOutListRequest)

GetUnspentTxOutListResponse = _reflection.GeneratedProtocolMessageType('GetUnspentTxOutListResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETUNSPENTTXOUTLISTRESPONSE,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GetUnspentTxOutListResponse)
  })
_sym_db.RegisterMessage(GetUnspentTxOutListResponse)

GenerateEntropyResponse = _reflection.GeneratedProtocolMessageType('GenerateEntropyResponse', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEENTROPYRESPONSE,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GenerateEntropyResponse)
  })
_sym_db.RegisterMessage(GenerateEntropyResponse)

GetAccountKeyRequest = _reflection.GeneratedProtocolMessageType('GetAccountKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTKEYREQUEST,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GetAccountKeyRequest)
  })
_sym_db.RegisterMessage(GetAccountKeyRequest)

GetAccountKeyResponse = _reflection.GeneratedProtocolMessageType('GetAccountKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTKEYRESPONSE,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GetAccountKeyResponse)
  })
_sym_db.RegisterMessage(GetAccountKeyResponse)

GetPublicAddressRequest = _reflection.GeneratedProtocolMessageType('GetPublicAddressRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPUBLICADDRESSREQUEST,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GetPublicAddressRequest)
  })
_sym_db.RegisterMessage(GetPublicAddressRequest)

GetPublicAddressResponse = _reflection.GeneratedProtocolMessageType('GetPublicAddressResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPUBLICADDRESSRESPONSE,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GetPublicAddressResponse)
  })
_sym_db.RegisterMessage(GetPublicAddressResponse)

ReadRequestCodeRequest = _reflection.GeneratedProtocolMessageType('ReadRequestCodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _READREQUESTCODEREQUEST,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.ReadRequestCodeRequest)
  })
_sym_db.RegisterMessage(ReadRequestCodeRequest)

ReadRequestCodeResponse = _reflection.GeneratedProtocolMessageType('ReadRequestCodeResponse', (_message.Message,), {
  'DESCRIPTOR' : _READREQUESTCODERESPONSE,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.ReadRequestCodeResponse)
  })
_sym_db.RegisterMessage(ReadRequestCodeResponse)

GetRequestCodeRequest = _reflection.GeneratedProtocolMessageType('GetRequestCodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREQUESTCODEREQUEST,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GetRequestCodeRequest)
  })
_sym_db.RegisterMessage(GetRequestCodeRequest)

GetRequestCodeResponse = _reflection.GeneratedProtocolMessageType('GetRequestCodeResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETREQUESTCODERESPONSE,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GetRequestCodeResponse)
  })
_sym_db.RegisterMessage(GetRequestCodeResponse)

ReadTransferCodeRequest = _reflection.GeneratedProtocolMessageType('ReadTransferCodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _READTRANSFERCODEREQUEST,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.ReadTransferCodeRequest)
  })
_sym_db.RegisterMessage(ReadTransferCodeRequest)

ReadTransferCodeResponse = _reflection.GeneratedProtocolMessageType('ReadTransferCodeResponse', (_message.Message,), {
  'DESCRIPTOR' : _READTRANSFERCODERESPONSE,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.ReadTransferCodeResponse)
  })
_sym_db.RegisterMessage(ReadTransferCodeResponse)

GetTransferCodeRequest = _reflection.GeneratedProtocolMessageType('GetTransferCodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTRANSFERCODEREQUEST,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GetTransferCodeRequest)
  })
_sym_db.RegisterMessage(GetTransferCodeRequest)

GetTransferCodeResponse = _reflection.GeneratedProtocolMessageType('GetTransferCodeResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTRANSFERCODERESPONSE,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GetTransferCodeResponse)
  })
_sym_db.RegisterMessage(GetTransferCodeResponse)

ReadAddressCodeRequest = _reflection.GeneratedProtocolMessageType('ReadAddressCodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _READADDRESSCODEREQUEST,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.ReadAddressCodeRequest)
  })
_sym_db.RegisterMessage(ReadAddressCodeRequest)

ReadAddressCodeResponse = _reflection.GeneratedProtocolMessageType('ReadAddressCodeResponse', (_message.Message,), {
  'DESCRIPTOR' : _READADDRESSCODERESPONSE,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.ReadAddressCodeResponse)
  })
_sym_db.RegisterMessage(ReadAddressCodeResponse)

GetAddressCodeRequest = _reflection.GeneratedProtocolMessageType('GetAddressCodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETADDRESSCODEREQUEST,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GetAddressCodeRequest)
  })
_sym_db.RegisterMessage(GetAddressCodeRequest)

GetAddressCodeResponse = _reflection.GeneratedProtocolMessageType('GetAddressCodeResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETADDRESSCODERESPONSE,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GetAddressCodeResponse)
  })
_sym_db.RegisterMessage(GetAddressCodeResponse)

GenerateTxRequest = _reflection.GeneratedProtocolMessageType('GenerateTxRequest', (_message.Message,), {
  'DESCRIPTOR' : _GENERATETXREQUEST,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GenerateTxRequest)
  })
_sym_db.RegisterMessage(GenerateTxRequest)

GenerateTxResponse = _reflection.GeneratedProtocolMessageType('GenerateTxResponse', (_message.Message,), {
  'DESCRIPTOR' : _GENERATETXRESPONSE,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GenerateTxResponse)
  })
_sym_db.RegisterMessage(GenerateTxResponse)

GenerateOptimizationTxRequest = _reflection.GeneratedProtocolMessageType('GenerateOptimizationTxRequest', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEOPTIMIZATIONTXREQUEST,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GenerateOptimizationTxRequest)
  })
_sym_db.RegisterMessage(GenerateOptimizationTxRequest)

GenerateOptimizationTxResponse = _reflection.GeneratedProtocolMessageType('GenerateOptimizationTxResponse', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEOPTIMIZATIONTXRESPONSE,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GenerateOptimizationTxResponse)
  })
_sym_db.RegisterMessage(GenerateOptimizationTxResponse)

GenerateTransferCodeTxRequest = _reflection.GeneratedProtocolMessageType('GenerateTransferCodeTxRequest', (_message.Message,), {
  'DESCRIPTOR' : _GENERATETRANSFERCODETXREQUEST,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GenerateTransferCodeTxRequest)
  })
_sym_db.RegisterMessage(GenerateTransferCodeTxRequest)

GenerateTransferCodeTxResponse = _reflection.GeneratedProtocolMessageType('GenerateTransferCodeTxResponse', (_message.Message,), {
  'DESCRIPTOR' : _GENERATETRANSFERCODETXRESPONSE,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GenerateTransferCodeTxResponse)
  })
_sym_db.RegisterMessage(GenerateTransferCodeTxResponse)

GenerateTxFromTxOutListRequest = _reflection.GeneratedProtocolMessageType('GenerateTxFromTxOutListRequest', (_message.Message,), {
  'DESCRIPTOR' : _GENERATETXFROMTXOUTLISTREQUEST,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GenerateTxFromTxOutListRequest)
  })
_sym_db.RegisterMessage(GenerateTxFromTxOutListRequest)

GenerateTxFromTxOutListResponse = _reflection.GeneratedProtocolMessageType('GenerateTxFromTxOutListResponse', (_message.Message,), {
  'DESCRIPTOR' : _GENERATETXFROMTXOUTLISTRESPONSE,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GenerateTxFromTxOutListResponse)
  })
_sym_db.RegisterMessage(GenerateTxFromTxOutListResponse)

SubmitTxRequest = _reflection.GeneratedProtocolMessageType('SubmitTxRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITTXREQUEST,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.SubmitTxRequest)
  })
_sym_db.RegisterMessage(SubmitTxRequest)

SubmitTxResponse = _reflection.GeneratedProtocolMessageType('SubmitTxResponse', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITTXRESPONSE,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.SubmitTxResponse)
  })
_sym_db.RegisterMessage(SubmitTxResponse)

GetLedgerInfoResponse = _reflection.GeneratedProtocolMessageType('GetLedgerInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLEDGERINFORESPONSE,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GetLedgerInfoResponse)
  })
_sym_db.RegisterMessage(GetLedgerInfoResponse)

GetBlockInfoRequest = _reflection.GeneratedProtocolMessageType('GetBlockInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKINFOREQUEST,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GetBlockInfoRequest)
  })
_sym_db.RegisterMessage(GetBlockInfoRequest)

GetBlockInfoResponse = _reflection.GeneratedProtocolMessageType('GetBlockInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKINFORESPONSE,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GetBlockInfoResponse)
  })
_sym_db.RegisterMessage(GetBlockInfoResponse)

ArchiveBlockSignatureData = _reflection.GeneratedProtocolMessageType('ArchiveBlockSignatureData', (_message.Message,), {
  'DESCRIPTOR' : _ARCHIVEBLOCKSIGNATUREDATA,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.ArchiveBlockSignatureData)
  })
_sym_db.RegisterMessage(ArchiveBlockSignatureData)

GetBlockRequest = _reflection.GeneratedProtocolMessageType('GetBlockRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKREQUEST,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GetBlockRequest)
  })
_sym_db.RegisterMessage(GetBlockRequest)

GetBlockResponse = _reflection.GeneratedProtocolMessageType('GetBlockResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKRESPONSE,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GetBlockResponse)
  })
_sym_db.RegisterMessage(GetBlockResponse)

GetTxStatusAsSenderRequest = _reflection.GeneratedProtocolMessageType('GetTxStatusAsSenderRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTXSTATUSASSENDERREQUEST,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GetTxStatusAsSenderRequest)
  })
_sym_db.RegisterMessage(GetTxStatusAsSenderRequest)

GetTxStatusAsSenderResponse = _reflection.GeneratedProtocolMessageType('GetTxStatusAsSenderResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTXSTATUSASSENDERRESPONSE,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GetTxStatusAsSenderResponse)
  })
_sym_db.RegisterMessage(GetTxStatusAsSenderResponse)

GetTxStatusAsReceiverRequest = _reflection.GeneratedProtocolMessageType('GetTxStatusAsReceiverRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTXSTATUSASRECEIVERREQUEST,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GetTxStatusAsReceiverRequest)
  })
_sym_db.RegisterMessage(GetTxStatusAsReceiverRequest)

GetTxStatusAsReceiverResponse = _reflection.GeneratedProtocolMessageType('GetTxStatusAsReceiverResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTXSTATUSASRECEIVERRESPONSE,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GetTxStatusAsReceiverResponse)
  })
_sym_db.RegisterMessage(GetTxStatusAsReceiverResponse)

GetProcessedBlockRequest = _reflection.GeneratedProtocolMessageType('GetProcessedBlockRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROCESSEDBLOCKREQUEST,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GetProcessedBlockRequest)
  })
_sym_db.RegisterMessage(GetProcessedBlockRequest)

GetProcessedBlockResponse = _reflection.GeneratedProtocolMessageType('GetProcessedBlockResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPROCESSEDBLOCKRESPONSE,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GetProcessedBlockResponse)
  })
_sym_db.RegisterMessage(GetProcessedBlockResponse)

GetBalanceRequest = _reflection.GeneratedProtocolMessageType('GetBalanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBALANCEREQUEST,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GetBalanceRequest)
  })
_sym_db.RegisterMessage(GetBalanceRequest)

GetBalanceResponse = _reflection.GeneratedProtocolMessageType('GetBalanceResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBALANCERESPONSE,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GetBalanceResponse)
  })
_sym_db.RegisterMessage(GetBalanceResponse)

SendPaymentRequest = _reflection.GeneratedProtocolMessageType('SendPaymentRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENDPAYMENTREQUEST,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.SendPaymentRequest)
  })
_sym_db.RegisterMessage(SendPaymentRequest)

SendPaymentResponse = _reflection.GeneratedProtocolMessageType('SendPaymentResponse', (_message.Message,), {
  'DESCRIPTOR' : _SENDPAYMENTRESPONSE,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.SendPaymentResponse)
  })
_sym_db.RegisterMessage(SendPaymentResponse)

GetNetworkStatusResponse = _reflection.GeneratedProtocolMessageType('GetNetworkStatusResponse', (_message.Message,), {

  'PeerBlockIndexMapEntry' : _reflection.GeneratedProtocolMessageType('PeerBlockIndexMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETNETWORKSTATUSRESPONSE_PEERBLOCKINDEXMAPENTRY,
    '__module__' : 'mobilecoind_api_pb2'
    # @@protoc_insertion_point(class_scope:mobilecoind_api.GetNetworkStatusResponse.PeerBlockIndexMapEntry)
    })
  ,
  'DESCRIPTOR' : _GETNETWORKSTATUSRESPONSE,
  '__module__' : 'mobilecoind_api_pb2'
  # @@protoc_insertion_point(class_scope:mobilecoind_api.GetNetworkStatusResponse)
  })
_sym_db.RegisterMessage(GetNetworkStatusResponse)
_sym_db.RegisterMessage(GetNetworkStatusResponse.PeerBlockIndexMapEntry)


DESCRIPTOR._options = None
_TXPROPOSAL_OUTLAYINDEXTOTXOUTINDEXENTRY._options = None
_GETNETWORKSTATUSRESPONSE_PEERBLOCKINDEXMAPENTRY._options = None

_MOBILECOINDAPI = _descriptor.ServiceDescriptor(
  name='MobilecoindAPI',
  full_name='mobilecoind_api.MobilecoindAPI',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=6367,
  serialized_end=9204,
  methods=[
  _descriptor.MethodDescriptor(
    name='AddMonitor',
    full_name='mobilecoind_api.MobilecoindAPI.AddMonitor',
    index=0,
    containing_service=None,
    input_type=_ADDMONITORREQUEST,
    output_type=_ADDMONITORRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveMonitor',
    full_name='mobilecoind_api.MobilecoindAPI.RemoveMonitor',
    index=1,
    containing_service=None,
    input_type=_REMOVEMONITORREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetMonitorList',
    full_name='mobilecoind_api.MobilecoindAPI.GetMonitorList',
    index=2,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETMONITORLISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetMonitorStatus',
    full_name='mobilecoind_api.MobilecoindAPI.GetMonitorStatus',
    index=3,
    containing_service=None,
    input_type=_GETMONITORSTATUSREQUEST,
    output_type=_GETMONITORSTATUSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetUnspentTxOutList',
    full_name='mobilecoind_api.MobilecoindAPI.GetUnspentTxOutList',
    index=4,
    containing_service=None,
    input_type=_GETUNSPENTTXOUTLISTREQUEST,
    output_type=_GETUNSPENTTXOUTLISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GenerateEntropy',
    full_name='mobilecoind_api.MobilecoindAPI.GenerateEntropy',
    index=5,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GENERATEENTROPYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetAccountKey',
    full_name='mobilecoind_api.MobilecoindAPI.GetAccountKey',
    index=6,
    containing_service=None,
    input_type=_GETACCOUNTKEYREQUEST,
    output_type=_GETACCOUNTKEYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetPublicAddress',
    full_name='mobilecoind_api.MobilecoindAPI.GetPublicAddress',
    index=7,
    containing_service=None,
    input_type=_GETPUBLICADDRESSREQUEST,
    output_type=_GETPUBLICADDRESSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ReadRequestCode',
    full_name='mobilecoind_api.MobilecoindAPI.ReadRequestCode',
    index=8,
    containing_service=None,
    input_type=_READREQUESTCODEREQUEST,
    output_type=_READREQUESTCODERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetRequestCode',
    full_name='mobilecoind_api.MobilecoindAPI.GetRequestCode',
    index=9,
    containing_service=None,
    input_type=_GETREQUESTCODEREQUEST,
    output_type=_GETREQUESTCODERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ReadTransferCode',
    full_name='mobilecoind_api.MobilecoindAPI.ReadTransferCode',
    index=10,
    containing_service=None,
    input_type=_READTRANSFERCODEREQUEST,
    output_type=_READTRANSFERCODERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetTransferCode',
    full_name='mobilecoind_api.MobilecoindAPI.GetTransferCode',
    index=11,
    containing_service=None,
    input_type=_GETTRANSFERCODEREQUEST,
    output_type=_GETTRANSFERCODERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ReadAddressCode',
    full_name='mobilecoind_api.MobilecoindAPI.ReadAddressCode',
    index=12,
    containing_service=None,
    input_type=_READADDRESSCODEREQUEST,
    output_type=_READADDRESSCODERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetAddressCode',
    full_name='mobilecoind_api.MobilecoindAPI.GetAddressCode',
    index=13,
    containing_service=None,
    input_type=_GETADDRESSCODEREQUEST,
    output_type=_GETADDRESSCODERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GenerateTx',
    full_name='mobilecoind_api.MobilecoindAPI.GenerateTx',
    index=14,
    containing_service=None,
    input_type=_GENERATETXREQUEST,
    output_type=_GENERATETXRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GenerateOptimizationTx',
    full_name='mobilecoind_api.MobilecoindAPI.GenerateOptimizationTx',
    index=15,
    containing_service=None,
    input_type=_GENERATEOPTIMIZATIONTXREQUEST,
    output_type=_GENERATEOPTIMIZATIONTXRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GenerateTransferCodeTx',
    full_name='mobilecoind_api.MobilecoindAPI.GenerateTransferCodeTx',
    index=16,
    containing_service=None,
    input_type=_GENERATETRANSFERCODETXREQUEST,
    output_type=_GENERATETRANSFERCODETXRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GenerateTxFromTxOutList',
    full_name='mobilecoind_api.MobilecoindAPI.GenerateTxFromTxOutList',
    index=17,
    containing_service=None,
    input_type=_GENERATETXFROMTXOUTLISTREQUEST,
    output_type=_GENERATETXFROMTXOUTLISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SubmitTx',
    full_name='mobilecoind_api.MobilecoindAPI.SubmitTx',
    index=18,
    containing_service=None,
    input_type=_SUBMITTXREQUEST,
    output_type=_SUBMITTXRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetLedgerInfo',
    full_name='mobilecoind_api.MobilecoindAPI.GetLedgerInfo',
    index=19,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETLEDGERINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetBlockInfo',
    full_name='mobilecoind_api.MobilecoindAPI.GetBlockInfo',
    index=20,
    containing_service=None,
    input_type=_GETBLOCKINFOREQUEST,
    output_type=_GETBLOCKINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetBlock',
    full_name='mobilecoind_api.MobilecoindAPI.GetBlock',
    index=21,
    containing_service=None,
    input_type=_GETBLOCKREQUEST,
    output_type=_GETBLOCKRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetTxStatusAsSender',
    full_name='mobilecoind_api.MobilecoindAPI.GetTxStatusAsSender',
    index=22,
    containing_service=None,
    input_type=_GETTXSTATUSASSENDERREQUEST,
    output_type=_GETTXSTATUSASSENDERRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetTxStatusAsReceiver',
    full_name='mobilecoind_api.MobilecoindAPI.GetTxStatusAsReceiver',
    index=23,
    containing_service=None,
    input_type=_GETTXSTATUSASRECEIVERREQUEST,
    output_type=_GETTXSTATUSASRECEIVERRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetProcessedBlock',
    full_name='mobilecoind_api.MobilecoindAPI.GetProcessedBlock',
    index=24,
    containing_service=None,
    input_type=_GETPROCESSEDBLOCKREQUEST,
    output_type=_GETPROCESSEDBLOCKRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetBalance',
    full_name='mobilecoind_api.MobilecoindAPI.GetBalance',
    index=25,
    containing_service=None,
    input_type=_GETBALANCEREQUEST,
    output_type=_GETBALANCERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SendPayment',
    full_name='mobilecoind_api.MobilecoindAPI.SendPayment',
    index=26,
    containing_service=None,
    input_type=_SENDPAYMENTREQUEST,
    output_type=_SENDPAYMENTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetNetworkStatus',
    full_name='mobilecoind_api.MobilecoindAPI.GetNetworkStatus',
    index=27,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETNETWORKSTATUSRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_MOBILECOINDAPI)

DESCRIPTOR.services_by_name['MobilecoindAPI'] = _MOBILECOINDAPI

# @@protoc_insertion_point(module_scope)
